#ifdef __FreeBSD_kernel__

#include_next <sys/_types.h>

#else

#ifndef _SYS__TYPES_H_
#define _SYS__TYPES_H_

#include <sys/cdefs.h>
#include <machine/_types.h>

#endif /* !_SYS__TYPES_H_ */

#endif
