#include_next <stdint.h>

#ifndef _SYS_STDINT_H_
#define _SYS_STDINT_H_

#include <sys/cdefs.h>

#ifdef __FreeBSD_kernel__
#include <sys/_types.h>
#include <machine/_stdint.h>
#include <sys/_stdint.h>
#endif

#endif
